@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.0';
+our $VERSION = '1.01';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -226,6 +226,16 @@ sub authorize {
 	return $self->get_token(%rest);
 }
 
+sub authorized {
+	my $self = shift;
+	return (!$self->{last_token} || $self->{last_token} <= time - 3600) ? 0 : 1;
+}
+
+sub has_token {
+	my $self = shift;
+	return $self->authorized();
+}
+
 sub json_request {
     my ($self, $method, $path, $query, $post_data) = @_;
     DEBUG('%4s JSON', $method);
@@ -717,13 +727,12 @@ __END__
 
 =head1 NAME
 
-Reddit::Client - A perl wrapper for Reddit
+Reddit::Client - A Perl wrapper for the Reddit API
 
 =head1 SYNOPSIS
 
     use Reddit::Client;
 
-    # You'll need these 4 pieces of information for every script:
     my $client_id  = "DFhtrhBgfhhRTd";
     my $secret     = "KrDNsbeffdbILOdgbgSvSBsbfFs";
     my $username   = "reddit-username";
@@ -739,13 +748,13 @@ Reddit::Client - A perl wrapper for Reddit
 	password	=> $password,
     );
 	
-    # Or create object then authenticate. Useful if you need to authenticate more than once, for example if you were to check the inboxes of several accounts
+    # Or create object then authenticate. 
+    # Useful if you need to authenticate more than once, for example if you were to check the inboxes of several accounts
     my $reddit       = Reddit::Client->new(
         user_agent   => 'MyApp/1.0',
     );
 
-    # Get oauth token. This replaces the "login" method.
-    $reddit->authorize(
+    $reddit->get_token(
 	client_id	=> $client_id,
 	secret		=> $secret,
 	username	=> $username,
@@ -766,7 +775,7 @@ Reddit::Client - A perl wrapper for Reddit
 
 =head1 DESCRIPTION
 
-Reddit::Client provides methods and simple object wrappers for objects exposed
+Reddit::Client provides methods and object wrappers for objects exposed
 by the Reddit API. This module handles HTTP communication, oauth session management, and communication with Reddit's external API.
 
 For more information about the Reddit API, see L<https://github.com/reddit/reddit/wiki/API>.
@@ -811,39 +820,42 @@ When set to true, outputs a small amount of debugging information.
 
 =item new(user_agent => , [client_id =>, secret =>, username=>, password =>])
 
-Begins a new reddit session. 
-If C<session_file> is provided, it will be read and parsed as JSON. If
-session data is found, it is restored. Otherwise, a new session is started.
-Session data does not restore the user_agent string of the original session.
-
-=item authenticated
-
-Returns true if there is an oauth token.
+Creates a new Reddit::Client object. Optionally authenticates at the same time. If any of the four optional arguments are used, all are required.
 
 
-=item save_session($path)
+=item get_token(client_id =>, secret =>, username=>, password =>)
 
-Saves the current session to C<$path>. Throws an error if the user is not logged
-in. C<$path> is only required if the Reddit::Client instance was created without
-the C<session_file> parameter.
+Get an Oauth token from Reddit. The client ID and secret come  from your apps page, where you will first have to register the script: L<https://www.reddit.com/prefs/apps>. Only the account that created the app and accounts that are registered as developers for the app will be able to use it. 
+
+For a Perl script, select a "script" type app. The "about url" and "redirect uri" can be any address; they are not used for scripts. 
 
 
-=item load_session($path)
+=item authorize()
 
-Attempts to load the session from C<$path>. When successful, returns true and
-stores the session file path for future use.
+Alias for get_token().
 
 
-=item login($usr, $pwd)
+=item has_token()
 
-Attempts to log the user in. Throws an error on failure.
+Return true if a valid Oauth token exists.
 
 
-=item me
+=item authorized()
+
+Alias for has_token().
+
+
+=item me()
 
 Returns a Reddit::Client::Account object.
 
 
+=item info($item_id)
+
+Returns a has of information about C<$item_id>, which must be a complete name
+(e.g., t3_xxxxx).
+
+
 =item list_subreddits($type)
 
 Returns a list of Reddit::Client::SubReddit objects for C<$type>, where C<$type>
@@ -880,10 +892,6 @@ Syntactic sugar for C<list_subreddits(SUBREDDITS_POPULAR)>.
 Syntactic sugar for C<list_subreddits(SUBREDDITS_NEW)>.
 
 
-=item info($item_id)
-
-Returns a has of information about C<$item_id>, which must be a complete name
-(e.g., t3_xxxxx).
 
 
 =item find_subreddits($query)
@@ -891,13 +899,15 @@ Returns a has of information about C<$item_id>, which must be a complete name
 Returns a list of SubReddit objects matching C<$query>.
 
 
-=item fetch_links(subreddit => ..., view => ..., limit => ..., before => ..., after => ...)
+=item fetch_links([subreddit => ...], [view => ...], [limit => ...], [before => ...], [after => ...])
 
-Returns a list of links from a reddit page. If C<subreddit> is specified,
-the list of links is returned from the desired subreddit. Otherwise, the
-links will be from the front page. C<view> specifieds the feed (e.g.
+Returns a list of links.
+
+All arguments are optional. If C<subreddit> is specified,
+the list of links is returned from the desired subreddit or multi (i.e. "pics+new"). Otherwise, the
+links will be from the front page of the authenticated user (i.e. what you would see as the front page if you logged in as that user) . C<view> specifieds the feed (e.g.
 C<VIEW_NEW> or C<VIEW_HOT>). C<limit> may be used to limit the number of
-objects returned, and C<before> and C<after> denote the placeholders for
+objects returned; Reddit returns a maximum of 100. C<before> and C<after> denote the placeholders for
 slicing the feed up, just as the reddit urls themselves do. Data is returned
 as a hash with three keys, I<before>, I<after>, and I<items>.
 
@@ -915,26 +925,12 @@ Submits a link to a reddit. Returns the id of the new link.
 =item submit_text(subreddit => ..., title => ..., text => ...)
 
 Submits a self-post to a reddit. Returns the id of the new post.
+ 
 
 =item get_subreddit_comments([subreddit => ...][before => ...][after => ...][limit => ...])
 
 Return a list of Reddit::Client::Comment objects from a subreddit or multi. All arguments are optional. If subreddit is ommitted, a multi of the subscribed subreddits from the authenticating account will be returned (i.e. what you see when you visit reddit.com's from page and are logged in). If limit is ommitted, Reddit's default limit of 25 is used. If limit is present but false, this is interpreted as no limit and the maximum is returned (100).
 
-=item get_comments($permalink)
-
-Disabled in the current version (0.93).
-
-Returns a list ref of Reddit::Client::Comment objects underneath the
-the specified URL C<$permalink>. Unfortunately, this is the only
-method available via the API. Comments may be more easily accessed
-via the Link object, which implicitly provides the C<$permalink>
-parameter.
-
-    my $links = $reddit->fetch_links(...);
-    foreach (@{$links->{items}}) {
-        my $comments = $_->comments();
-    }
-
 
 =item submit_comment(parent_id => ..., text => ...)
 
